#! /bin/sh
# last modified: 2000-08-26
#
# A small script to use netscape by clicking an URL-button.

netscape=/usr/local/bin/netscape

if [ "$1" != "" ]; then
  if [ -x $netscape ]; then
    $netscape -remote "openURL($1,new-window)" || $netscape "$1" &
  else
    echo "browser.sh: Failed to start '$netscape'!"
  fi
fi
